************************************************************************************************
*
*  Written by:  Gregory A. Green
*               3832 Forest Creek Way
*               Martinez, GA  30907
*
*  Program:     THERM.PRG 1993 Gregory A. Green
*
*               August 1993, Revision 0
*               Developed for FoxPro for Windows, V2.5
*
*  Description: Routine for displaying a status bar based on percent complete. The user is
*               only required to initialize the status bar with the total number of items
*               (or records) to process, and then make successive calls to update the status
*               bar based on incrementing the number of items to process.
*
*  Globals:     last_record
*
************************************************************************************************
*
*  Example usage of the routines
*
PUBLIC last_record                               && Used in displaying status progress bar
PRIVATE cur_rec, num_rec, ndx


	cur_rec = 1                                   && Set to first record
	num_rec = 35                                  && Set to total number to process

	DO display_status_window WITH num_rec,"Please Wait -- Processing Records"
	DO update_status_window WITH cur_rec, .T.     && TRUE for text, FALSE for no text

	DO WHILE cur_rec <= num_rec
		DO update_status_window WITH cur_rec, .T.  && Call with each successive processed record
		cur_rec = cur_rec + 1
		FOR ndx=1 TO 500                           && Just a pause loop
		ENDFOR
	ENDDO
	DO deact_status_window                        && Complete and close status window
RETURN

************************************************************************************************
*
*  Routine for setting the current working database and renaming old databases
*
PROCEDURE display_status_window
PARAMETER num_rec, status_msg

	IF NOT WEXIST("status_ind")
		DEFINE WINDOW status_ind AT 0.000, 0.000 SIZE 6.063,85.429 FONT "MS Sans Serif", 8 ;
			NOFLOAT NOCLOSE NOMINIMIZE NONE COLOR RGB(,,,192,192,192)
		MOVE WINDOW status_ind CENTER
	ENDIF
	last_record = num_rec                         && Initialize number of records to process
	IF WVISIBLE("status_ind")
		ACTIVATE WINDOW status_ind SAME
	ELSE
		ACTIVATE WINDOW status_ind NOSHOW
	ENDIF
	CLEAR
	@ 2.875, 5.286 TO 4.563,80.000 PEN 1, 8 COLOR RGB(128,128,128,,,,)
	@ 4.500, 5.429 TO 4.500,80.000 PEN 1, 8 STYLE "1" COLOR RGB(255,255,255,255,255,255)
	@ 2.938,79.857 TO 4.563,79.857 PEN 1, 8 COLOR RGB(255,255,255,255,255,255)
	@ 2.875, 5.286 TO 4.500, 5.286 PEN 6, 8 COLOR RGB(0,0,128,0,0,128)
	@ 0.000, 0.000 TO 6.063, 0.000 PEN 1, 8 COLOR RGB(255,255,255,255,255,255)
	@ 0.000,85.286 TO 6.063,85.286 PEN 1, 8 COLOR RGB(128,128,128,128,128,128)
	@ 5.563, 1.000 TO 5.563,84.714 PEN 1, 8 STYLE "1" COLOR RGB(255,255,255,255,255,255)
	@ 6.000, 0.000 TO 6.000,85.286 PEN 1, 8 STYLE "1" COLOR RGB(128,128,128,128,128,128)
	@ 0.375, 1.000 TO 0.375,84.857 PEN 1, 8 STYLE "1" COLOR RGB(128,128,128,128,128,128)
	@ 0.000, 0.000 TO 0.000,85.286 PEN 1, 8 STYLE "1" COLOR RGB(255,255,255,255,255,255)
	@ 0.313, 0.857 TO 5.626, 0.857 PEN 1, 8 COLOR RGB(128,128,128,128,128,128)
	@ 0.313,84.571 TO 5.626,84.571 PEN 1, 8 COLOR RGB(255,255,255,255,255,255)
	@ 0.813,9.000 SAY status_msg SIZE 1.000,78.667 FONT "Arial", 10 STYLE "B" PICTURE "@TI"
RETURN

************************************************************************************************
*
*  Routine for updating the status window to reflect amount completed
*
PROCEDURE update_status_window
PARAMETER current_record, display_percent
	PRIVATE progress, m_width, percnt

	IF NOT WVISIBLE("status_ind")
		ACTIVATE WINDOW status_ind
	ENDIF
	progress = current_record/last_record         && Get percentage of records processed
	m_width = 5.429 + (progress * 75)             && Set width of the progress meter
	@ 2.875,5.429 TO 4.563,m_width PATTERN 1 COLOR RGB(0,0,128,0,0,128)
	IF display_percent
		percnt = STR(100 * progress) + " %"
		IF m_width < 39
			@ 3.188,39.000 SAY ALLTRIM(percnt) SIZE 1.000,8.500 FONT "Arial", 10 PICTURE "@TI" STYLE "B"
		ELSE
			@ 3.188,39.000 SAY ALLTRIM(percnt) SIZE 1.000,8.500 FONT "Arial", 10 PICTURE "@TI" STYLE "BT" COLOR RGB(255,255,255,0,0,128)
		ENDIF
	ENDIF
RETURN

************************************************************************************************
*
*  Routine for deactivating the status window to reflect amount completed
*
PROCEDURE deact_status_window

	@ 2.875,5.429 TO 4.563,80.0 PATTERN 1 COLOR RGB(0,0,128,0,0,128)
	IF WEXIST("status_ind")
		DEACTIVATE WINDOW status_ind
		RELEASE WINDOW status_ind
	ENDIF
RETURN
